# HAWC2 Models

Collection of pip-installable hawc2 models.

## Installation

```
pip install hawc2models
```


# Example


```python
from hawc2models import IEA22MW
htc = IEA22MW('IEA-22-280-RWT')
```


